import {
  VOLUME_CONVERSION_TABLE,
  WEIGHT_CONVERSION_TABLE
} from "./chunk-V26OCCTL.mjs";
import {
  UNITS
} from "./chunk-YZB3IG47.mjs";
import {
  assert
} from "./chunk-YY3SUQ7P.mjs";

// src/lib/unit.ts
var UnitUtils = class {
  static getUnit(unit) {
    const match = UNITS.find((u) => u.abbreviation === unit || u.name === unit);
    assert(match, (match2) => !!match2, `No unit found for key: ${unit}`);
    return match;
  }
  static getConversionRatio(from, to) {
    const { type, abbreviation } = this.getUnit(from);
    const conversionTable = type === "volume" ? VOLUME_CONVERSION_TABLE : WEIGHT_CONVERSION_TABLE;
    const lookupTable = conversionTable[abbreviation];
    assert(
      lookupTable,
      (lookupTable2) => !!lookupTable2[to],
      `No conversion table available for unit ${from} to ${to}`
    );
    return lookupTable[to];
  }
  /**
   * Converts a number from one unit to another
   *
   * @param amount - The amount to convert
   * @param from - The unit to convert from
   * @param to - The unit to convert to
   * @returns - The converted amount
   */
  static convert(amount, from, to) {
    if (from === to) {
      return amount;
    }
    const ratio = this.getConversionRatio(from, to);
    return amount * ratio;
  }
};

export {
  UnitUtils
};
