import {
  warn
} from "./chunk-YY3SUQ7P.mjs";
import {
  IS_DEV
} from "./chunk-XV4QN4LA.mjs";

// src/lib/recipe.ts
var RecipeUtilsImpl = class {
  scopedMessageFactory(recipe) {
    return (message) => `${recipe.name}: ${message}`;
  }
  validateConfig(config) {
    if (!IS_DEV) {
      return;
    }
    const msg = this.scopedMessageFactory(config);
    warn(
      config.instructions,
      (instructions) => instructions.length > 0,
      msg("Recipe has no instructions")
    );
    warn(
      config.serves,
      (serves) => serves === void 0 || serves > 0,
      msg("Recipe serves less than 1 person")
    );
    warn(
      config.ingredients,
      (ingredients) => ingredients.length > 0,
      msg("Recipe has no ingredients")
    );
  }
  determineMeasurementSystem(config) {
    const { ingredients } = config;
    const hasMetric = ingredients.some(
      (ingredient) => {
        var _a;
        return (_a = ingredient.conversion) == null ? void 0 : _a.metric;
      }
    );
    const hasImperial = ingredients.some(
      (ingredient) => {
        var _a;
        return (_a = ingredient.conversion) == null ? void 0 : _a["us-customary"];
      }
    );
    if (hasMetric && hasImperial) {
      return "both";
    }
    if (hasMetric) {
      return "metric";
    }
    if (hasImperial) {
      return "us-customary";
    }
    return "none";
  }
  create(config) {
    this.validateConfig(config);
    return {
      name: config.name,
      ingredients: config.ingredients,
      // optional
      thumbnail: config.thumbnail,
      serves: config.serves ?? 1,
      instructions: config.instructions ?? []
    };
  }
};
var RecipeUtils = new RecipeUtilsImpl();

export {
  RecipeUtils
};
