import { UNITS } from './const/unit.mjs';

type ConversionTables = 'us-customary' | 'metric';
type Unit = (typeof UNITS)[number];
type UnitName = Unit['name'];
type UnitAbbreviation = Unit['abbreviation'];
type UnitKey = UnitName | UnitAbbreviation;
type PartialBy<T, K extends keyof T> = Omit<T, K> & Partial<Pick<T, K>>;
type IngredientAmount = {
    value: number;
    unit: UnitKey;
};
type Ingredient = {
    name: string;
    amount: IngredientAmount;
    conversion?: Partial<Record<ConversionTables, IngredientAmount | UnitKey>>;
    notes?: string;
};
type Instruction = {
    name: string;
    description: string;
    image?: string;
};
type GlobalRecipeConfig = {};
type Recipe = GlobalRecipeConfig & {
    name: string;
    thumbnail?: string;
    ingredients: Ingredient[];
    serves: number;
    instructions: string[];
    measurements?: ConversionTables;
};
type recipeOmittableKeys = 'serves';
type RecipeConfig = PartialBy<Recipe, recipeOmittableKeys>;

export type { ConversionTables, GlobalRecipeConfig, Ingredient, IngredientAmount, Instruction, Recipe, RecipeConfig, Unit, UnitAbbreviation, UnitKey, UnitName };
